async fn handshake(
stream: &mut TcpStream,
hs: HandshakeState,
) -> Result<TransportState, NetworkError>Expand description
Perform a noise handshake as initiator with the remote party.
async fn handshake(
stream: &mut TcpStream,
hs: HandshakeState,
) -> Result<TransportState, NetworkError>Perform a noise handshake as initiator with the remote party.